Documentation
¶
Index ¶
- func NetworkManagementConnectivityTest_IsConstruct(x interface{}) *bool
- func NetworkManagementConnectivityTest_TfResourceType() *string
- func NewNetworkManagementConnectivityTestDestinationOutputReference_Override(n NetworkManagementConnectivityTestDestinationOutputReference, ...)
- func NewNetworkManagementConnectivityTestSourceOutputReference_Override(n NetworkManagementConnectivityTestSourceOutputReference, ...)
- func NewNetworkManagementConnectivityTestTimeoutsOutputReference_Override(n NetworkManagementConnectivityTestTimeoutsOutputReference, ...)
- func NewNetworkManagementConnectivityTest_Override(n NetworkManagementConnectivityTest, scope constructs.Construct, id *string, ...)
- type NetworkManagementConnectivityTest
- type NetworkManagementConnectivityTestConfig
- type NetworkManagementConnectivityTestDestination
- type NetworkManagementConnectivityTestDestinationOutputReference
- type NetworkManagementConnectivityTestSource
- type NetworkManagementConnectivityTestSourceOutputReference
- type NetworkManagementConnectivityTestTimeouts
- type NetworkManagementConnectivityTestTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NetworkManagementConnectivityTest_IsConstruct ¶
func NetworkManagementConnectivityTest_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func NetworkManagementConnectivityTest_TfResourceType ¶
func NetworkManagementConnectivityTest_TfResourceType() *string
func NewNetworkManagementConnectivityTestDestinationOutputReference_Override ¶
func NewNetworkManagementConnectivityTestDestinationOutputReference_Override(n NetworkManagementConnectivityTestDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkManagementConnectivityTestSourceOutputReference_Override ¶
func NewNetworkManagementConnectivityTestSourceOutputReference_Override(n NetworkManagementConnectivityTestSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkManagementConnectivityTestTimeoutsOutputReference_Override ¶
func NewNetworkManagementConnectivityTestTimeoutsOutputReference_Override(n NetworkManagementConnectivityTestTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewNetworkManagementConnectivityTest_Override ¶
func NewNetworkManagementConnectivityTest_Override(n NetworkManagementConnectivityTest, scope constructs.Construct, id *string, config *NetworkManagementConnectivityTestConfig)
Create a new {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test google_network_management_connectivity_test} Resource.
Types ¶
type NetworkManagementConnectivityTest ¶
type NetworkManagementConnectivityTest interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() *float64
// Experimental.
SetCount(val *float64)
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Destination() NetworkManagementConnectivityTestDestinationOutputReference
DestinationInput() *NetworkManagementConnectivityTestDestination
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
Protocol() *string
SetProtocol(val *string)
ProtocolInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RelatedProjects() *[]*string
SetRelatedProjects(val *[]*string)
RelatedProjectsInput() *[]*string
Source() NetworkManagementConnectivityTestSourceOutputReference
SourceInput() *NetworkManagementConnectivityTestSource
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() NetworkManagementConnectivityTestTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDestination(value *NetworkManagementConnectivityTestDestination)
PutSource(value *NetworkManagementConnectivityTestSource)
PutTimeouts(value *NetworkManagementConnectivityTestTimeouts)
ResetDescription()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetProtocol()
ResetRelatedProjects()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test google_network_management_connectivity_test}.
func NewNetworkManagementConnectivityTest ¶
func NewNetworkManagementConnectivityTest(scope constructs.Construct, id *string, config *NetworkManagementConnectivityTestConfig) NetworkManagementConnectivityTest
Create a new {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test google_network_management_connectivity_test} Resource.
type NetworkManagementConnectivityTestConfig ¶
type NetworkManagementConnectivityTestConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count *float64 `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// destination block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#destination NetworkManagementConnectivityTest#destination}
Destination *NetworkManagementConnectivityTestDestination `field:"required" json:"destination" yaml:"destination"`
// Unique name for the connectivity test.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#name NetworkManagementConnectivityTest#name}
Name *string `field:"required" json:"name" yaml:"name"`
// source block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#source NetworkManagementConnectivityTest#source}
Source *NetworkManagementConnectivityTestSource `field:"required" json:"source" yaml:"source"`
// The user-supplied description of the Connectivity Test. Maximum of 512 characters.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#description NetworkManagementConnectivityTest#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#id NetworkManagementConnectivityTest#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user-provided metadata.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#labels NetworkManagementConnectivityTest#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#project NetworkManagementConnectivityTest#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// IP Protocol of the test. When not provided, "TCP" is assumed.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#protocol NetworkManagementConnectivityTest#protocol}
Protocol *string `field:"optional" json:"protocol" yaml:"protocol"`
// Other projects that may be relevant for reachability analysis. This is applicable to scenarios where a test can cross project boundaries.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#related_projects NetworkManagementConnectivityTest#related_projects}
RelatedProjects *[]*string `field:"optional" json:"relatedProjects" yaml:"relatedProjects"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#timeouts NetworkManagementConnectivityTest#timeouts}
Timeouts *NetworkManagementConnectivityTestTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type NetworkManagementConnectivityTestDestination ¶
type NetworkManagementConnectivityTestDestination struct {
// A Compute Engine instance URI.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#instance NetworkManagementConnectivityTest#instance}
Instance *string `field:"optional" json:"instance" yaml:"instance"`
// The IP address of the endpoint, which can be an external or internal IP.
//
// An IPv6 address is only allowed when the test's
// destination is a global load balancer VIP.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#ip_address NetworkManagementConnectivityTest#ip_address}
IpAddress *string `field:"optional" json:"ipAddress" yaml:"ipAddress"`
// A Compute Engine network URI.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#network NetworkManagementConnectivityTest#network}
Network *string `field:"optional" json:"network" yaml:"network"`
// The IP protocol port of the endpoint. Only applicable when protocol is TCP or UDP.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#port NetworkManagementConnectivityTest#port}
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Project ID where the endpoint is located.
//
// The Project ID can be
// derived from the URI if you provide a VM instance or network URI.
// The following are two cases where you must provide the project ID:
// 1. Only the IP address is specified, and the IP address is within
// a GCP project. 2. When you are using Shared VPC and the IP address
// that you provide is from the service project. In this case, the
// network that the IP address resides in is defined in the host
// project.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#project_id NetworkManagementConnectivityTest#project_id}
ProjectId *string `field:"optional" json:"projectId" yaml:"projectId"`
}
type NetworkManagementConnectivityTestDestinationOutputReference ¶
type NetworkManagementConnectivityTestDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Instance() *string
SetInstance(val *string)
InstanceInput() *string
InternalValue() *NetworkManagementConnectivityTestDestination
SetInternalValue(val *NetworkManagementConnectivityTestDestination)
IpAddress() *string
SetIpAddress(val *string)
IpAddressInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
ProjectId() *string
SetProjectId(val *string)
ProjectIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInstance()
ResetIpAddress()
ResetNetwork()
ResetPort()
ResetProjectId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkManagementConnectivityTestDestinationOutputReference ¶
func NewNetworkManagementConnectivityTestDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkManagementConnectivityTestDestinationOutputReference
type NetworkManagementConnectivityTestSource ¶
type NetworkManagementConnectivityTestSource struct {
// A Compute Engine instance URI.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#instance NetworkManagementConnectivityTest#instance}
Instance *string `field:"optional" json:"instance" yaml:"instance"`
// The IP address of the endpoint, which can be an external or internal IP.
//
// An IPv6 address is only allowed when the test's
// destination is a global load balancer VIP.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#ip_address NetworkManagementConnectivityTest#ip_address}
IpAddress *string `field:"optional" json:"ipAddress" yaml:"ipAddress"`
// A Compute Engine network URI.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#network NetworkManagementConnectivityTest#network}
Network *string `field:"optional" json:"network" yaml:"network"`
// Type of the network where the endpoint is located. Possible values: ["GCP_NETWORK", "NON_GCP_NETWORK"].
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#network_type NetworkManagementConnectivityTest#network_type}
NetworkType *string `field:"optional" json:"networkType" yaml:"networkType"`
// The IP protocol port of the endpoint. Only applicable when protocol is TCP or UDP.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#port NetworkManagementConnectivityTest#port}
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Project ID where the endpoint is located.
//
// The Project ID can be
// derived from the URI if you provide a VM instance or network URI.
// The following are two cases where you must provide the project ID:
//
// 1. Only the IP address is specified, and the IP address is
// within a GCP project.
// 2. When you are using Shared VPC and the IP address
// that you provide is from the service project. In this case,
// the network that the IP address resides in is defined in the
// host project.
//
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#project_id NetworkManagementConnectivityTest#project_id}
ProjectId *string `field:"optional" json:"projectId" yaml:"projectId"`
}
type NetworkManagementConnectivityTestSourceOutputReference ¶
type NetworkManagementConnectivityTestSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Instance() *string
SetInstance(val *string)
InstanceInput() *string
InternalValue() *NetworkManagementConnectivityTestSource
SetInternalValue(val *NetworkManagementConnectivityTestSource)
IpAddress() *string
SetIpAddress(val *string)
IpAddressInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
NetworkType() *string
SetNetworkType(val *string)
NetworkTypeInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
ProjectId() *string
SetProjectId(val *string)
ProjectIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInstance()
ResetIpAddress()
ResetNetwork()
ResetNetworkType()
ResetPort()
ResetProjectId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkManagementConnectivityTestSourceOutputReference ¶
func NewNetworkManagementConnectivityTestSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkManagementConnectivityTestSourceOutputReference
type NetworkManagementConnectivityTestTimeouts ¶
type NetworkManagementConnectivityTestTimeouts struct {
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#create NetworkManagementConnectivityTest#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#delete NetworkManagementConnectivityTest#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google/r/network_management_connectivity_test#update NetworkManagementConnectivityTest#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type NetworkManagementConnectivityTestTimeoutsOutputReference ¶
type NetworkManagementConnectivityTestTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewNetworkManagementConnectivityTestTimeoutsOutputReference ¶
func NewNetworkManagementConnectivityTestTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) NetworkManagementConnectivityTestTimeoutsOutputReference
Source Files
¶
- networkmanagementconnectivitytest.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTest.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestConfig.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestDestination.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestDestinationOutputReference.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestDestinationOutputReference__runtime_type_checks.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestSource.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestSourceOutputReference.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestSourceOutputReference__runtime_type_checks.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestTimeouts.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestTimeoutsOutputReference.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTestTimeoutsOutputReference__runtime_type_checks.go
- networkmanagementconnectivitytest_NetworkManagementConnectivityTest__runtime_type_checks.go